pub enum BuiltinFunction {
Show 83 variants
GetWindowScaleFactor,
GetWindowDefaultFontSize,
AnimationTick,
Debug,
Mod,
Round,
Ceil,
Floor,
Abs,
Sqrt,
Cos,
Sin,
Tan,
ACos,
ASin,
ATan,
ATan2,
Log,
Ln,
Pow,
Exp,
ToFixed,
ToPrecision,
ToStringUnlocalized,
SetFocusItem,
ClearFocusItem,
ShowPopupWindow,
ClosePopupWindow,
ShowPopupMenu,
ShowPopupMenuInternal,
SetSelectionOffsets,
ItemFontMetrics,
StringToFloat,
StringIsFloat,
StringIsEmpty,
StringCharacterCount,
StringToLowercase,
StringToUppercase,
KeysToString,
ColorRgbaStruct,
ColorHsvaStruct,
ColorOklchStruct,
ColorBrighter,
ColorDarker,
ColorTransparentize,
ColorMix,
ColorWithAlpha,
ImageSize,
ArrayLength,
Rgb,
Hsv,
Oklch,
ColorScheme,
AccentColor,
SupportsNativeMenuBar,
SetupMenuBar,
SetupSystemTrayIcon,
Use24HourFormat,
MonthDayCount,
MonthOffset,
FormatDate,
DateNow,
ValidDate,
ParseDate,
TextInputFocused,
SetTextInputFocused,
ImplicitLayoutInfo(Orientation),
ItemAbsolutePosition,
RegisterCustomFontByPath,
RegisterCustomFontByMemory,
RegisterBitmapFont,
Translate,
UpdateTimers,
DetectOperatingSystem,
StartTimer,
StopTimer,
RestartTimer,
OpenUrl,
MacosBringAllWindowsToFront,
ParseMarkdown,
StringToStyledText,
ColorToStyledText,
DecimalSeparator,
}Expand description
A function built into the run-time
Variants
GetWindowScaleFactor
GetWindowDefaultFontSize
AnimationTick
Debug
Mod
Round
Ceil
Floor
Abs
Sqrt
Cos
Sin
Tan
ACos
ASin
ATan
ATan2
Log
Ln
Pow
Exp
ToFixed
ToPrecision
ToStringUnlocalized
SetFocusItem
ClearFocusItem
ShowPopupWindow
ClosePopupWindow
ShowPopupMenu
Show a context popup menu.
Arguments are (parent, menu_tree, position)
The first argument (parent) is a reference to the ContextMenu native item
The second argument (menu_tree) is a ElementReference to the root of the tree,
and in the LLR, a NumberLiteral to an index in crate::llr::SubComponent::menu_item_trees
ShowPopupMenuInternal
Show a context popup menu from a list of entries.
Arguments are (parent, entries, position)
The entries argument is an array of MenuEntry
SetSelectionOffsets
ItemFontMetrics
StringToFloat
the “42”.to_float()
StringIsFloat
the “42”.is_float()
StringIsEmpty
the “42”.is_empty
StringCharacterCount
the “42”.length
StringToLowercase
StringToUppercase
KeysToString
ColorRgbaStruct
ColorHsvaStruct
ColorOklchStruct
ColorBrighter
ColorDarker
ColorTransparentize
ColorMix
ColorWithAlpha
ImageSize
ArrayLength
Rgb
Hsv
Oklch
ColorScheme
AccentColor
SupportsNativeMenuBar
SetupMenuBar
Setup the menu bar
arguments are: (ref entries, ref sub-menu, ref activated, item_tree_root, no_native_menu_bar, <condition>)
item_tree_root is a reference to the MenuItem tree root (just like in the Self::ShowPopupMenu call).
no_native_menu_bar is a boolean literal that is true when we shouldn’t try to setup the native menu bar.
condition is an optional expression that is the expression to if condition : MenuBar { ... } for optional menu
SetupSystemTrayIcon
Setup the menu of a SystemTrayIcon.
Arguments are (system_tray_ref, menu_tree_root) where menu_tree_root is an ElementReference to the root of
the MenuItem tree, lowered to a NumberLiteral index into crate::llr::SubComponent::menu_item_trees in the LLR.
Use24HourFormat
MonthDayCount
MonthOffset
FormatDate
DateNow
ValidDate
ParseDate
TextInputFocused
SetTextInputFocused
ImplicitLayoutInfo(Orientation)
ItemAbsolutePosition
RegisterCustomFontByPath
RegisterCustomFontByMemory
RegisterBitmapFont
Translate
UpdateTimers
DetectOperatingSystem
StartTimer
StopTimer
RestartTimer
OpenUrl
MacosBringAllWindowsToFront
ParseMarkdown
StringToStyledText
ColorToStyledText
Converts a color to a hex string wrapped in StyledText.
Used for <font color='\{expr}'> interpolation in @markdown,
because parse_interpolated takes StyledText arguments.
DecimalSeparator
Implementations