pub struct TwoWayBinding {
pub property: NamedReference,
pub field_access: Vec<SmolStr>,
}Expand description
The right hand side of a two way binding
Fields
property: NamedReferenceThe property being linked
field_access: Vec<SmolStr>If property is a struct, this is the fields.
So if you have foo <=> element.property.baz.xyz, then field_access is vec!["baz", "xyz"]
Implementations