Struct

Struct Struct 

pub struct Struct {
    pub fields: BTreeMap<SmolStr, Type>,
    pub field_defaults: BTreeMap<SmolStr, ConstantExpression>,
    pub name: StructName,
}

Fields

fields: BTreeMap<SmolStr, Type>field_defaults: BTreeMap<SmolStr, ConstantExpression>

Default values for the fields. The expressions are resolved, converted to the field type, and constant-folded. Like the syntax node in name, this is ignored by Type’s equality comparison.

name: StructName

Implementations

Source

impl Struct

pub fn new(fields: BTreeMap<SmolStr, Type>, name: impl Into<StructName>) -> Self

Create a struct without declared field default values.

pub fn node(&self) -> Option<&SourceLocation>

Where a user-declared struct was written (for the language server).

pub fn rust_attributes(&self) -> &[SmolStr]

The raw text of each @rust-attr(...) on a user-declared struct.

pub fn field_order(&self) -> &[SmolStr]

The field names in declaration order for a user-declared struct.

pub fn default_value_for_field(&self, name: &SmolStr) -> Expression

The default value for the given field: the user-declared default if there is one, otherwise the default value for the field’s type.