pub enum FlexboxLayoutDirection {
Row,
RowReverse,
Column,
ColumnReverse,
}Variants
Row
Items are laid out in rows (horizontal primary axis)
RowReverse
Items are laid out in rows in reverse order (horizontal primary axis, right to left)
Column
Items are laid out in columns (vertical primary axis)
ColumnReverse
Items are laid out in columns in reverse order (vertical primary axis, bottom to top)