pub fn binding_reference(
element: &ElementRc,
name: &'static str,
) -> Option<NamedReference>Expand description
Return a named reference to a property if a binding is set on that property
pub fn binding_reference(
element: &ElementRc,
name: &'static str,
) -> Option<NamedReference>Return a named reference to a property if a binding is set on that property