pub struct GridLayout {
pub elems: Vec<GridLayoutElement>,
pub geometry: LayoutGeometry,
pub dialog_button_roles: Option<Vec<SmolStr>>,
pub uses_auto: bool,
}Expand description
Internal representation of a grid layout
Fields
elems: Vec<GridLayoutElement>All the elements which will be laid out within that element.
geometry: LayoutGeometryWhen this GridLayout is actually the layout of a Dialog, then the cells start with all the buttons, and this variable contains their roles. The string is actually one of the values from the i_slint_core::layout::DialogButtonRole
uses_auto: boolWhether any of the row/column expressions use ‘auto’
Implementations
Sourceimpl GridLayout
impl GridLayout
Sourcepub fn clone_cells(&mut self)
pub fn clone_cells(&mut self)
Clone each element’s cell into a new Rc, breaking any Rc sharing with the original.
pub fn visit_rowcol_named_references( &mut self, visitor: &mut impl FnMut(&mut NamedReference), )
pub fn visit_named_references( &mut self, visitor: &mut impl FnMut(&mut NamedReference), )