pub struct CompilationUnit {
pub public_components: Vec<PublicComponent>,
pub sub_components: TiVec<SubComponentIdx, SubComponent>,
pub used_sub_components: Vec<SubComponentIdx>,
pub globals: TiVec<GlobalIdx, GlobalComponent>,
pub popup_menu: Option<PopupMenu>,
pub has_debug_info: bool,
pub type_exports: Vec<TypeExport>,
pub translations: Option<Translations>,
}Fields
public_components: Vec<PublicComponent>sub_components: TiVec<SubComponentIdx, SubComponent>Storage for all sub-components
used_sub_components: Vec<SubComponentIdx>The sub-components that are not item-tree root
globals: TiVec<GlobalIdx, GlobalComponent>has_debug_info: booltype_exports: Vec<TypeExport>Every name the generated module re-exports for a declared type, plus the
renamed export { Original as Alias } aliases of components. Types renamed to
resolve a same-name collision are absent: they were never public. (Global
aliases are on GlobalComponent::aliases.)
translations: Option<Translations>Available on crate feature
bundle-translations only.Implementations
Sourceimpl CompilationUnit
impl CompilationUnit
pub fn needs_window_adapter(&self) -> bool
pub fn for_each_sub_components<'a>( &'a self, visitor: &mut dyn FnMut(SubComponentIdx, &'a SubComponent, &EvaluationContext<'_>), )
pub fn for_each_expression<'a>( &'a self, visitor: &mut dyn FnMut(&'a MutExpression, &EvaluationContext<'_>), )
Sourcepub fn for_each_z_order_expression<'a>(
&'a self,
visitor: &mut dyn FnMut(&'a MutExpression, &EvaluationContext<'_>),
)
pub fn for_each_z_order_expression<'a>( &'a self, visitor: &mut dyn FnMut(&'a MutExpression, &EvaluationContext<'_>), )
Visit the z-order expressions of all item tree nodes. The context passed to the visitor is the one of the item tree’s root sub-component, which is the frame the expressions are resolved in.