pub struct ResolvedModelTwoWayBinding<'a> {
pub parent_level: usize,
pub body_sub_component: SubComponentIdx,
pub data_prop: PropertyIdx,
pub data_prop_ty: &'a Type,
pub index_prop: PropertyIdx,
pub parent_sub_component: SubComponentIdx,
pub repeater_index: RepeatedElementIdx,
}Expand description
Resolved view of a model two-way binding, used by code generators to avoid re-deriving the parent walk and the data/index/repeater references.
Fields
parent_level: usizeNumber of parent hops up to the body sub-component.
body_sub_component: SubComponentIdxdata_prop: PropertyIdxdata_prop_ty: &'a TypeType of data_prop, i.e. the starting type of TwoWayBinding::field_access.
index_prop: PropertyIdxparent_sub_component: SubComponentIdxrepeater_index: RepeatedElementIdxAuto Trait Implementations
impl<'a> !RefUnwindSafe for ResolvedModelTwoWayBinding<'a>
impl<'a> !Send for ResolvedModelTwoWayBinding<'a>
impl<'a> !Sync for ResolvedModelTwoWayBinding<'a>
impl<'a> !UnwindSafe for ResolvedModelTwoWayBinding<'a>
impl<'a> Freeze for ResolvedModelTwoWayBinding<'a>
impl<'a> Unpin for ResolvedModelTwoWayBinding<'a>
impl<'a> UnsafeUnpin for ResolvedModelTwoWayBinding<'a>