InitCode

Struct InitCode 

pub struct InitCode {
    pub constructor_code: Vec<Expression>,
    pub focus_setting_code: Vec<Expression>,
    pub font_registration_code: Vec<Expression>,
    pub inlined_init_code: BTreeMap<usize, Expression>,
}

Fields

constructor_code: Vec<Expression>focus_setting_code: Vec<Expression>

Code to set the initial focus via forward-focus on the Window

font_registration_code: Vec<Expression>

Code to register embedded fonts.

inlined_init_code: BTreeMap<usize, Expression>

Code inserted from inlined components, ordered by offset of the place where it was inlined from. This way we can preserve the order across multiple inlining passes.

Implementations

Source

impl InitCode

pub fn iter(&self) -> impl Iterator<Item = &Expression>

pub fn iter_without_font_registration( &self, ) -> impl Iterator<Item = &Expression>

The init code without the font registration, which has to run before the property init.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Expression>